<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_d706c160e45bf7434fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2" . "V5cw=="), "_44e986c04f41a08b56a383c" . "7b3a88ee2" => base64_decode("c2VuZG" . "Vy"), "_956cd32298a229f9768" . "f1096f077ace3" => base64_decode("Ym9k" . "eS1w" . "bGFp" . "bg=="), "_f39f5346e313e4dd1ac3" . "a7bd8032beda" => base64_decode("c3Vic3RyX2Nv" . "bXBhcmU="), "_1d6c68a0262e8f" . "a0bed1215b7224a" . "98e" => base64_decode("cmV" . "jaX" . "BpZ" . "W50"), "_f589476007fa133f" . "457c3ef29ddfa566" => base64_decode("V" . "G" . "8" . "="), "_97ea09a7faf27c52c6e" . "ff69773df1d8a" => base64_decode("dGltZXN0YW1" . "w"), "_9c050c786fc87" . "170cbb84fc6a8b" . "13cb6" => base64_decode("YXR0Y" . "WNobW" . "VudC0" . "="), "_a1e707d02a236dadebd15a45e65ebdb" . "6" => base64_decode("YXR0YWN" . "obWVudC" . "1jb3Vud" . "A=="), "_618a4aeb9fe" . "cc4592a4521f" . "34876fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_8c575917cbaedf1e7" . "efae84939402bff" => base64_decode("U3ViamVjd" . "A=="), "_6e1c717cf3cbf1af982ed74" . "d4336b7f1" => base64_decode("Ym9keS" . "1odG1s"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_d706c160e45bf7434fff82a5976f0e" . "19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_a1e707d02a236dadebd15a45e" . "65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_f39f5346e" . "313e4dd1ac" . "3a7bd8032b" . "eda"]($key, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_9c050c786fc87170cbb84fc6a8b13" . "cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_1d6c68a0262e8fa0bed1" . "215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_618a4aeb9fecc" . "4592a4521f3487" . "6fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_f589476007fa1" . "33f457c3ef29dd" . "fa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_8c575917cbaedf1e7efae849" . "39402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_6e1c717" . "cf3cbf1a" . "f982ed74" . "d4336b7f" . "1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_956cd322" . "98a229f97" . "68f1096f0" . "77ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_97ea09a7faf27c52c6eff69" . "773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_44e986c04f41" . "a08b56a383c7b" . "3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}