<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array("_618a4aeb9fec" . "c4592a4521f34" . "876fa29" => base64_decode("ZnJvb" . "Q=="), "_460e1aeb3113a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3Mg" . "ZW1haWwgZm9yIGluZm9jYXB0" . "dXJlIHByb2plY3Q="), "_03b1f0ce" . "e835582d1" . "158dce267" . "8b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcH" . "R1cmUgbWFpbCByZWNlaXZl" . "ZCBzdWJzY3JpYmVy"), "_bfda889b74ea561b14325e3" . "0e7d75426" => base64_decode("Ym9k" . "eV9o" . "dG1s"), "_376d30c40857357a4d4cbb1" . "ffaa25817" => base64_decode("d" . "G" . "8" . "="), "_9b16fa2" . "683095e6" . "7d7c8b26" . "5a8081d0" . "b" => base64_decode("TWFpbFJlY2VpdmVkRXZl" . "bnRSZWNlaXZlcg=="), "project_i" . "d" => base64_decode("cHJvamV" . "jdF9pZA" . "=="), "_c35473364fa7a050299058f3" . "32ec29c1" => base64_decode("ZXhj" . "ZXB0" . "aW9u"), "_ced92d7b391285c8a26846f1f4bd3" . "128" => base64_decode("Ym9keV9" . "0ZXh0"), "_67a0d624aeb" . "cceb0abd5ce5" . "6a53ff06f" => base64_decode("ZGF0ZQ" . "=="), "_a3d82c5df38e194c" . "9c73e3ccb4223bbc" => base64_decode("ZW1haWxfZGF0Y" . "Q=="), "_f656816961e8573806141" . "c558b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_e608e5b5c4c34a67b" . "a97ef84c1e16199" => base64_decode("J" . "w" . "=" . "="), "_5d40a2cf1c525fb252bf5599e" . "339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdC" . "B3YXMgaWRlbnRpZmllZCBmb3IgbWFp" . "bDsgc3ViamVjdCAn"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9b16fa2683095e67d7c8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_03b1f0cee" . "835582d115" . "8dce2678b5" . "05c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_5d40a2cf1c525fb252bf5599e339fdd" . "0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_e608e5b5c4c34a67ba97ef84c1e1619" . "9"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_618a4aeb9fecc4592a4521f" . "34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_376d30c40857357a" . "4d4cbb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f656816961e" . "8573806141c5" . "58b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_ced92d7b391285c8a26846f1f4bd3" . "128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_bfda889b74ea5" . "61b14325e30e7d" . "75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_67a0d624aebcceb0abd5ce56a53ff" . "06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_460e1aeb3113a1676ce59a8f4" . "0431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["project" . "_id"] => $project->GetId(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_a3d82c5df" . "38e194c9c7" . "3e3ccb4223" . "bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_c35473364fa7a050299058" . "f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}